Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2357)

Unified Diff: content/public/browser/browser_plugin_guest_manager.h

Issue 261363002: Rename BrowserPluginGuestManagerDelegate to BrowserPluginGuestManager (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@guestview_manager_cleanupguestmanager
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/browser_plugin_guest_manager.h
diff --git a/content/public/browser/browser_plugin_guest_manager_delegate.h b/content/public/browser/browser_plugin_guest_manager.h
similarity index 79%
rename from content/public/browser/browser_plugin_guest_manager_delegate.h
rename to content/public/browser/browser_plugin_guest_manager.h
index c55f58e984c2902adbc33bffe78492df1e162290..db478c993e0930aa36a8136c9c222440b1e4b58f 100644
--- a/content/public/browser/browser_plugin_guest_manager_delegate.h
+++ b/content/public/browser/browser_plugin_guest_manager.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_PUBLIC_BROWSER_BROWSER_PLUGIN_GUEST_MANAGER_DELEGATE_H_
-#define CONTENT_PUBLIC_BROWSER_BROWSER_PLUGIN_GUEST_MANAGER_DELEGATE_H_
+#ifndef CONTENT_PUBLIC_BROWSER_BROWSER_PLUGIN_GUEST_MANAGER_H_
+#define CONTENT_PUBLIC_BROWSER_BROWSER_PLUGIN_GUEST_MANAGER_H_
#include "base/callback.h"
#include "content/common/content_export.h"
@@ -19,16 +19,16 @@ namespace content {
class SiteInstance;
class WebContents;
// A BrowserPluginGuestManagerDelegate offloads guest management and routing
// operations outside of the content layer.
struct StorageInfo {
bool persist;
std::string partition_id;
};
-class CONTENT_EXPORT BrowserPluginGuestManagerDelegate {
+class CONTENT_EXPORT BrowserPluginGuestManager {
public:
- virtual ~BrowserPluginGuestManagerDelegate() {}
+ virtual ~BrowserPluginGuestManager() {}
virtual content::WebContents* CreateGuest(
content::SiteInstance* embedder_site_instance,
@@ -57,4 +57,4 @@ class CONTENT_EXPORT BrowserPluginGuestManagerDelegate {
} // namespace content
-#endif // CONTENT_PUBLIC_BROWSER_BROWSER_PLUGIN_GUEST_MANAGER_DELEGATE_H_
+#endif // CONTENT_PUBLIC_BROWSER_BROWSER_PLUGIN_GUEST_MANAGER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -19,16 +19,16 @@ namespace content {
class SiteInstance;
class WebContents;
-// A BrowserPluginGuestManagerDelegate offloads guest management and routing
+// A BrowserPluginGuestManager offloads guest management and routing
// operations outside of the content layer.
struct StorageInfo {